@@ -68,46 +68,13 @@
 #include <qstring.h>
 #include <qstringlist.h>
 #include "XmlStorableEvent.h"
-
+#include "XmlSubHandler.h"
 
 namespace Rosegarden
 {
 
 using namespace BaseProperties;
 
-class XmlSubHandler
-{
-public:
-    XmlSubHandler();
-    virtual ~XmlSubHandler();
-    
-    virtual bool startElement(const QString& namespaceURI,
-                              const QString& localName,
-                              const QString& qName,
-                              const QXmlAttributes& atts) = 0;
-
-    /**
-     * @param finished : if set to true on return, means that
-     * the handler should be deleted
-     */
-    virtual bool endElement(const QString& namespaceURI,
-                            const QString& localName,
-                            const QString& qName,
-                            bool& finished) = 0;
-
-    virtual bool characters(const QString& ch) = 0;
-};
-
-XmlSubHandler::XmlSubHandler()
-{
-}
-
-XmlSubHandler::~XmlSubHandler()
-{
-}
-
-//----------------------------------------
-
 class ConfigurationXmlSubHandler : public XmlSubHandler
 {
 public:
@@ -258,6 +225,7 @@ RoseXmlHandler::RoseXmlHandler(RosegardenGUIDoc *doc,
         m_lsb(0),
         m_instrument(0),
         m_plugin(0),
+        m_pluginInBuss(false),
         m_colourMap(0),
         m_keyMapping(0),
         m_pluginId(0),
@@ -843,7 +811,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         QString segmentType = (atts.value("type")).lower();
         if (segmentType) {
             if (segmentType == "audio") {
-
                 int audioFileId = atts.value("file").toInt();
 
                 // check this file id exists on the AudioFileManager
@@ -861,16 +828,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
                 m_currentSegment = new Segment(Segment::Audio);
                 m_currentSegment->setAudioFileId(audioFileId);
                 m_currentSegment->setStartTime(startTime);
-
-                QString unstretchedStr = atts.value("unstretched");
-
-                if (unstretchedStr) {
-                    int unstretchedFileId = unstretchedStr.toInt();
-                    m_currentSegment->setUnstretchedFileId(unstretchedFileId);
-                    double ratio = atts.value("stretch").toDouble();
-                    m_currentSegment->setStretchRatio(ratio);
-                }
-
             } else {
                 // Create a (normal) internal Segment
                 m_currentSegment = new Segment(Segment::Internal);
@@ -1697,11 +1654,15 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
 
         PluginContainer *container = 0;
 
-        if (m_section == InInstrument)
+        if (m_section == InInstrument) {
+//            std::cerr << "Found plugin in instrument" << std::endl;
             container = m_instrument;
-        else if (m_section == InBuss)
+            m_pluginInBuss = false;
+        } else if (m_section == InBuss) {
+//            std::cerr << "Found plugin in buss" << std::endl;
             container = m_buss;
-        else {
+            m_pluginInBuss = true;
+        } else {
             m_errorString = "Found Plugin outside Instrument or Buss";
             return false;
         }
@@ -1710,6 +1671,9 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
         // have a valid one.
         //
         if (container) {
+
+//            std::cerr << "Have container" << std::endl;
+
             emit setOperationName(i18n("Loading plugins..."));
             ProgressDialog::processEvents();
 
@@ -1752,6 +1716,8 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
                     plugin = apm->getPluginByIdentifier(identifier);
             }
 
+//            std::cerr << "Plugin identifier " << identifier << " -> plugin " << plugin << std::endl;
+
             // If we find the plugin all is well and good but if
             // we don't we just skip it.
             //
@@ -1765,6 +1731,7 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
                     m_plugin->setAssigned(true);
                     m_plugin->setBypass(bypassed);
                     m_plugin->setIdentifier(plugin->getIdentifier().data());
+//                    std::cerr << "set identifier to plugin at position " << position << std::endl;
                     if (program != "") {
                         m_plugin->setProgram(program);
                     }
@@ -2160,7 +2127,11 @@ RoseXmlHandler::endElement(const QString& namespaceURI,
 
     } else if (lcName == "plugin") {
 
-        m_section = InInstrument;
+        if (m_pluginInBuss) {
+            m_section = InBuss;
+        } else {
+            m_section = InInstrument;
+        }
         m_plugin = 0;
         m_pluginId = 0;
 
