@@ -34,7 +34,7 @@
 #include "base/Segment.h"
 #include "base/Studio.h"
 #include "gui/application/RosegardenGUIApp.h"
-#include "gui/editors/segment/AudioPreviewThread.h"
+#include "gui/editors/segment/segmentcanvas/AudioPreviewThread.h"
 #include <map>
 #include "sound/AudioFileManager.h"
 // #include <qlist.h>  (fixes problem for Adam Dingle)
@@ -553,6 +553,16 @@ protected:
      */
     QString getAutoSaveFileName();
 
+    /**
+     * Save document to the given file.  This function does the actual
+     * save of the file to the given filename; saveDocument() wraps
+     * this, saving to a temporary file and then renaming to the
+     * required file, so as not to lose the original if a failure
+     * occurs during overwriting.
+     */
+    bool saveDocumentActual(const QString &filename, QString& errMsg,
+                            bool autosave = false);
+
     /**
      * Save one segment to the given text stream
      */
