@@ -70,42 +70,54 @@ MusicXmlExporter::writeNote(Event *e, timeT lastNoteTime,
 {
     str << "\t\t\t<note>" << std::endl;
 
+    Pitch pitch(64);
+    Accidental acc;
+    Accidental displayAcc;
+    bool cautionary;
+    Accidental processedDisplayAcc;
+
     if (e->isa(Note::EventRestType)) {
         str << "\t\t\t\t<rest/>" << std::endl;
 
     } else {
 
+        // Order of MusicXML elements within a note:
+        // chord
+        // pitch
+        // duration
+        // tie
+        // instrument
+        // voice
+        // type
+        // dot(s)
+        // accidental
+        // time modification
+        // stem
+        // notehead
+        // staff
+        // beam
+        // notations
+        // lyric
+
         if (e->getNotationAbsoluteTime() == lastNoteTime) {
             str << "\t\t\t\t<chord/>" << std::endl;
         } else {
             accTable.update();
         }
 
-        if (e->has(TIED_BACKWARD) &&
-                e->get
-                <Bool>(TIED_BACKWARD)) {
-            str << "\t\t\t\t<tie type=\"stop\"/>" << std::endl;
-        }
-        if (e->has(TIED_FORWARD) &&
-                e->get
-                <Bool>(TIED_FORWARD)) {
-            str << "\t\t\t\t<tie type=\"start\"/>" << std::endl;
-        }
-
         str << "\t\t\t\t<pitch>" << std::endl;
 
         long p = 0;
-        e->get
-        <Int>(PITCH, p);
-        Pitch pitch(p);
+        e->get<Int>(PITCH, p);
+        pitch = p;
 
         str << "\t\t\t\t\t<step>" << pitch.getNoteName(key) << "</step>" << std::endl;
 
-        Accidental acc(pitch.getAccidental(key.isSharp()));
-        Accidental displayAcc(pitch.getDisplayAccidental(key));
+        acc = pitch.getAccidental(key.isSharp());
+        displayAcc = pitch.getDisplayAccidental(key);
 
-        bool cautionary = false;
-        Accidental processedDisplayAcc =
+        cautionary = false;
+        processedDisplayAcc =
             accTable.processDisplayAccidental
             (displayAcc, pitch.getHeightOnStaff(clef, key), cautionary);
 
@@ -127,6 +139,49 @@ MusicXmlExporter::writeNote(Event *e, timeT lastNoteTime,
         str << "\t\t\t\t\t<octave>" << octave << "</octave>" << std::endl;
 
         str << "\t\t\t\t</pitch>" << std::endl;
+    }
+
+    // Since there's no way to provide the performance absolute time
+    // for a note, there's also no point in providing the performance
+    // duration, even though it might in principle be of interest
+    str << "\t\t\t\t<duration>" << e->getNotationDuration() << "</duration>" << std::endl;
+
+    if (!e->isa(Note::EventRestType)) {
+
+        if (e->has(TIED_BACKWARD) &&
+                e->get
+                <Bool>(TIED_BACKWARD)) {
+            str << "\t\t\t\t<tie type=\"stop\"/>" << std::endl;
+        }
+        if (e->has(TIED_FORWARD) &&
+                e->get
+                <Bool>(TIED_FORWARD)) {
+            str << "\t\t\t\t<tie type=\"start\"/>" << std::endl;
+        }
+
+        // Incomplete: will RG ever use this?
+        str << "\t\t\t\t<voice>" << "1" << "</voice>" << std::endl;
+    }
+
+    Note note = Note::getNearestNote(e->getNotationDuration());
+
+    static const char *noteNames[] = {
+        "64th", "32nd", "16th", "eighth", "quarter", "half", "whole", "breve"
+    };
+
+    int noteType = note.getNoteType();
+    if (noteType < 0 || noteType >= int(sizeof(noteNames) / sizeof(noteNames[0]))) {
+        std::cerr << "WARNING: MusicXmlExporter::writeNote: bad note type "
+        << noteType << std::endl;
+        noteType = 4;
+    }
+
+    str << "\t\t\t\t<type>" << noteNames[noteType] << "</type>" << std::endl;
+    for (int i = 0; i < note.getDots(); ++i) {
+        str << "\t\t\t\t<dot/>" << std::endl;
+    }
+
+    if (!e->isa(Note::EventRestType)) {
 
         if (processedDisplayAcc == Accidentals::DoubleFlat) {
             str << "\t\t\t\t<accidental>flat-flat</accidental>" << std::endl;
@@ -164,43 +219,17 @@ MusicXmlExporter::writeNote(Event *e, timeT lastNoteTime,
         }
     }
 
-    // Since there's no way to provide the performance absolute time
-    // for a note, there's also no point in providing the performance
-    // duration, even though it might in principle be of interest
-    str << "\t\t\t\t<duration>" << e->getNotationDuration() << "</duration>" << std::endl;
-
-    // Incomplete: will RG ever use this?
-    str << "\t\t\t\t<voice>" << "1" << "</voice>" << std::endl;
-    Note note = Note::getNearestNote(e->getNotationDuration(), MAX_DOTS);
-
-    static const char *noteNames[] = {
-                                         "64th", "32nd", "16th", "eighth", "quarter", "half", "whole", "breve"
-                                     };
-
-    int noteType = note.getNoteType();
-    if (noteType < 0 || noteType >= int(sizeof(noteNames) / sizeof(noteNames[0]))) {
-        std::cerr << "WARNING: MusicXmlExporter::writeNote: bad note type "
-        << noteType << std::endl;
-        noteType = 4;
-    }
-
-    str << "\t\t\t\t<type>" << noteNames[noteType] << "</type>" << std::endl;
-    for (int i = 0; i < note.getDots(); ++i) {
-        str << "\t\t\t\t<dot/>" << std::endl;
-    }
-
     // could also do <stem>down</stem> if you wanted
     str << "\t\t\t</note>" << std::endl;
 }
 
 void
-MusicXmlExporter::writeKey(Event *event, std::ofstream &str)
+MusicXmlExporter::writeKey(Rosegarden::Key whichKey, std::ofstream &str)
 {
-    Rosegarden::Key whichKey(*event);
     str << "\t\t\t\t<key>" << std::endl;
     str << "\t\t\t\t<fifths>"
-    << (whichKey.isSharp() ? "" : "-")
-    << (whichKey.getAccidentalCount()) << "</fifths>" << std::endl;
+        << (whichKey.isSharp() ? "" : "-")
+        << (whichKey.getAccidentalCount()) << "</fifths>" << std::endl;
     str << "\t\t\t\t<mode>";
     if (whichKey.isMinor()) {
         str << "minor";
@@ -221,12 +250,9 @@ MusicXmlExporter::writeTime(TimeSignature timeSignature, std::ofstream &str)
 }
 
 void
-MusicXmlExporter::writeClef(Event *event, std::ofstream &str)
+MusicXmlExporter::writeClef(Clef whichClef, std::ofstream &str)
 {
     str << "\t\t\t\t<clef>" << std::endl;
-    std::string whichClef = Clef::Treble;
-    event->get
-    <String>(Clef::ClefPropertyName, whichClef);
     if (whichClef == Clef::Treble) {
         str << "\t\t\t\t<sign>G</sign>" << std::endl;
         str << "\t\t\t\t<line>2</line>" << std::endl;
@@ -243,6 +269,22 @@ MusicXmlExporter::writeClef(Event *event, std::ofstream &str)
     str << "\t\t\t\t</clef>" << std::endl;
 }
 
+std::string
+MusicXmlExporter::numToId(int num)
+{
+    int base = num % 52;
+    char c;
+    if (base < 26) c = 'A' + char(base);
+    else c = 'a' + char(base - 26);
+    std::string s;
+    s += c;
+    while (num / 52 > 0) {
+        s += c;
+        num /= 52;
+    }
+    return s;
+}
+
 bool
 MusicXmlExporter::write()
 {
@@ -256,11 +298,11 @@ MusicXmlExporter::write()
 
     // XML header information
     str << "<?xml version=\"1.0\"?>" << std::endl;
-    str << "<!DOCTYPE score-partwise PUBLIC \"-//Recordare//DTD MusicXML 0.6 Partwise//EN\" \"http://www.musicxml.org/dtds/partwise.dtd\">" << std::endl;
+    str << "<!DOCTYPE score-partwise PUBLIC \"-//Recordare//DTD MusicXML 1.1 Partwise//EN\" \"http://www.musicxml.org/dtds/partwise.dtd\">" << std::endl;
     // MusicXml header information
     str << "<score-partwise>" << std::endl;
-    str << "\t<work> <work-title>" << m_fileName <<
-    "</work-title></work> " << std::endl;
+    str << "\t<work> <work-title>" << XmlExportable::encode(m_fileName)
+        << "</work-title></work> " << std::endl;
     // Movement, etc. info goes here
     str << "\t<identification> " << std::endl;
     if (composition->getCopyrightNote() != "") {
@@ -271,7 +313,7 @@ MusicXmlExporter::write()
     str << "\t\t<encoding>" << std::endl;
     // Incomplete: Insert date!
     //    str << "\t\t\t<encoding-date>" << << "</encoding-date>" << std::endl;
-    str << "\t\t\t<software>Rosegarden</software>" << std::endl;
+    str << "\t\t\t<software>Rosegarden v" VERSION "</software>" << std::endl;
     str << "\t\t</encoding>" << std::endl;
     str << "\t</identification> " << std::endl;
 
@@ -287,9 +329,14 @@ MusicXmlExporter::write()
         // Incomplete: What about all the other Midi stuff?
         // Incomplete: (Future) GUI to set labels if they're not already
         Instrument * trackInstrument = (&m_doc->getStudio())->getInstrumentById((*i).second->getInstrument());
-        str << "\t\t<score-part id=\"" << (*i).first << "\">" << std::endl;
-        str << "\t\t\t<part-name>" << (*i).second->getLabel() << "</part-name>" << std::endl;
+        str << "\t\t<score-part id=\"" << numToId((*i).first) << "\">" << std::endl;
+        str << "\t\t\t<part-name>" << XmlExportable::encode((*i).second->getLabel()) << "</part-name>" << std::endl;
         if (trackInstrument) {
+/*
+  Removing this stuff for now.  It doesn't work, because the ids are
+  are expected to be non-numeric names that refer to elements
+  elsewhere that define the actual instruments.  I think.
+
             str << "\t\t\t<score-instrument id=\"" << trackInstrument->getName() << "\">" << std::endl;
             str << "\t\t\t\t<instrument-name>" << trackInstrument->getType() << "</instrument-name>" << std::endl;
             str << "\t\t\t</score-instrument>" << std::endl;
@@ -299,6 +346,7 @@ MusicXmlExporter::write()
                 str << "\t\t\t\t<midi-program>" << ((unsigned int)trackInstrument->getProgramChange() + 1) << "</midi-program>" << std::endl;
             }
             str << "\t\t\t</midi-instrument>" << std::endl;
+*/
         }
         str << "\t\t</score-part>" << std::endl;
 
@@ -332,6 +380,10 @@ MusicXmlExporter::write()
         AccidentalTable accTable(key, clef);
         TimeSignature prevTimeSignature;
 
+        bool timeSigPending = false;
+        bool keyPending = false;
+        bool clefPending = false;
+
         for (CompositionTimeSliceAdapter::iterator k = adapter.begin();
                 k != adapter.end(); ++k) {
 
@@ -339,45 +391,80 @@ MusicXmlExporter::write()
             timeT absoluteTime = event->getNotationAbsoluteTime();
 
             if (!startedPart) {
-                str << "\t<part id=\"" << (*j).first << "\">" << std::endl;
+                str << "\t<part id=\"" << numToId((*j).first) << "\">" << std::endl;
                 startedPart = true;
             }
 
             // Open a new measure if necessary
             // Incomplete: How does MusicXML handle non-contiguous measures?
+
             int measureNumber = composition->getBarNumber(absoluteTime);
 
-            if (oldMeasureNumber < 0) {
-                str << "\t\t<measure number=\"" << (measureNumber + 1) << "\">" << std::endl;
-                str << "\t\t\t<attributes>" << std::endl;
-                // Divisions is divisions of crotchet (quarter-note) on which all
-                // note-lengths are based
-                str << "\t\t\t\t<divisions>" << Note(Note::Crotchet).getDuration() << "</divisions>" << std::endl;
-                prevTimeSignature = composition->getTimeSignatureAt(composition->getStartMarker());
-                writeTime(prevTimeSignature, str);
-                startedAttributes = true;
+            TimeSignature timeSignature = composition->getTimeSignatureAt(absoluteTime);
 
-            } else if (measureNumber > oldMeasureNumber) {
+            if (measureNumber != oldMeasureNumber) {
 
                 if (startedAttributes) {
+                    
+                    // rather bizarrely, MusicXML appears to require
+                    // key, time, clef in that order
+
+                    if (keyPending) {
+                        writeKey(key, str);
+                        keyPending = false;
+                    }
+                    if (timeSigPending) {
+                        writeTime(prevTimeSignature, str);
+                        timeSigPending = false;
+                    }
+                    if (clefPending) {
+                        writeClef(clef, str);
+                        clefPending = false;
+                    }
+
                     str << "\t\t\t</attributes>" << std::endl;
                     startedAttributes = false;
                 }
 
                 while (measureNumber > oldMeasureNumber) {
 
+                    bool first = (oldMeasureNumber < 0);
+
+                    if (!first) {
+                        if (startedAttributes) {
+                            str << "\t\t\t</attributes>" << std::endl;
+                        }                            
+                        str << "\t\t</measure>\n" << std::endl;
+                    }
+
                     ++oldMeasureNumber;
-                    str << "\t\t</measure>\n" << std::endl;
+
                     str << "\t\t<measure number=\"" << (oldMeasureNumber + 1) << "\">" << std::endl;
+
+                    if (first) {
+                        str << "\t\t\t<attributes>" << std::endl;
+                        // Divisions is divisions of crotchet (quarter-note) on which all
+                        // note-lengths are based
+                        str << "\t\t\t\t<divisions>" << Note(Note::Crotchet).getDuration() << "</divisions>" << std::endl;
+                        startedAttributes = true;
+                        timeSigPending = true;
+                    }
                 }
 
                 accTable = AccidentalTable(key, clef);
-
-            } else if (measureNumber < oldMeasureNumber) {
-                // Incomplete: Error!
             }
+
             oldMeasureNumber = measureNumber;
 
+            if (timeSignature != prevTimeSignature) {
+                prevTimeSignature = timeSignature;
+                timeSigPending = true;
+                if (!startedAttributes) {
+                    str << "\t\t\t<attributes>" << std::endl;
+                    startedAttributes = true;
+                }
+            }
+
             // process event
             if (event->isa(Rosegarden::Key::EventType)) {
 
@@ -385,8 +472,8 @@ MusicXmlExporter::write()
                     str << "\t\t\t<attributes>" << std::endl;
                     startedAttributes = true;
                 }
-                writeKey(event, str);
                 key = Rosegarden::Key(*event);
+                keyPending = true;
                 accTable = AccidentalTable(key, clef);
 
             } else if (event->isa(Clef::EventType)) {
@@ -395,26 +482,28 @@ MusicXmlExporter::write()
                     str << "\t\t\t<attributes>" << std::endl;
                     startedAttributes = true;
                 }
-                writeClef(event, str);
                 clef = Clef(*event);
+                clefPending = true;
                 accTable = AccidentalTable(key, clef);
 
             } else if (event->isa(Note::EventRestType) ||
                        event->isa(Note::EventType)) {
-
-                // Random TimeSignature events in the middle of nowhere will
-                // be ignored, for better or worse
-                TimeSignature timeSignature = composition->getTimeSignatureAt(absoluteTime);
-                if (timeSignature.getNumerator() != prevTimeSignature.getNumerator() ||
-                        timeSignature.getDenominator() != prevTimeSignature.getDenominator()) {
-                    if (!startedAttributes) {
-                        str << "\t\t\t<attributes>" << std::endl;
-                        startedAttributes = true;
-                    }
-                    writeTime(timeSignature, str);
-                    prevTimeSignature = timeSignature;
-                }
+                
                 if (startedAttributes) {
+                
+                    if (keyPending) {
+                        writeKey(key, str);
+                        keyPending = false;
+                    }
+                    if (timeSigPending) {
+                        writeTime(prevTimeSignature, str);
+                        timeSigPending = false;
+                    }
+                    if (clefPending) {
+                        writeClef(clef, str);
+                        clefPending = false;
+                    }
+
                     str << "\t\t\t</attributes>" << std::endl;
                     startedAttributes = false;
                 }
@@ -430,6 +519,25 @@ MusicXmlExporter::write()
         }
 
         if (startedPart) {
+            if (startedAttributes) {
+                
+                if (keyPending) {
+                    writeKey(key, str);
+                    keyPending = false;
+                }
+                if (timeSigPending) {
+                    writeTime(prevTimeSignature, str);
+                    timeSigPending = false;
+                }
+                if (clefPending) {
+                    writeClef(clef, str);
+                    clefPending = false;
+                }
+                
+                str << "\t\t\t</attributes>" << std::endl;
+                startedAttributes = false;
+            }
+
             str << "\t\t</measure>" << std::endl;
             str << "\t</part>" << std::endl;
         }
