@@ -76,7 +76,7 @@ class RealTime;
 class ProgressBar;
 class PlayListDialog;
 class MidiMixerWindow;
-class MarkerEditorDialog;
+class MarkerEditor;
 class MappedComposition;
 class LircCommander;
 class LircClient;
@@ -232,7 +232,12 @@ public:
     virtual void fastForwardToEnd()   { slotFastForwardToEnd(); }
     virtual void jumpToTime(int sec, int usec) { slotJumpToTime(sec, usec); }
     virtual void startAtTime(int sec, int usec) { slotStartAtTime(sec, usec); }
-
+    
+    virtual void trackUp()            { slotTrackUp(); }
+    virtual void trackDown()          { slotTrackDown(); }
+    virtual void toggleMutedCurrentTrack() { slotToggleMutedCurrentTrack(); }
+    virtual void toggleRecordCurrentTrack() { slotToggleRecordCurrentTrack(); }
+        
     /**
      * Start the sequencer auxiliary process
      * (built in the 'sequencer' directory)
@@ -654,6 +659,7 @@ public slots:
     /**
      * Export to a temporary file and process
      */
+    void slotPrintLilypond();
     void slotPreviewLilypond();
     void slotLilypondViewProcessExited(KProcess *);
 
@@ -1212,7 +1218,13 @@ public slots:
      */
     void slotMuteAllTracks();
     void slotUnmuteAllTracks();
-
+    void slotToggleMutedCurrentTrack();
+    
+    /**
+     * Toggle arm (record) current track
+     */
+    void slotToggleRecordCurrentTrack();
+    
     /**
      * save general Options like all bar positions and status as well
      * as the geometry and the recent file list to the configuration
@@ -1268,6 +1280,18 @@ public slots:
      */
     void slotDeleteTempo(timeT time);
 
+    /**
+     * Add marker
+     */
+    void slotAddMarker(timeT time);
+
+    /**
+     * Remove a marker
+     */
+    void slotDeleteMarker(timeT time,
+                          QString name,
+                          QString description);
+
     /**
      * Document modified
      */
@@ -1339,7 +1363,8 @@ public slots:
 
     void slotRepeatingSegments();
     void slotRelabelSegments();
-
+	void slotTransposeSegments();
+	
     /// Panic button pressed
     void slotPanic();
 
@@ -1498,6 +1523,8 @@ public slots:
 
     void slotShowToolHelp(const QString &);
 
+    void slotNewerVersionAvailable(QString);
+
 private:
 
 
@@ -1607,7 +1634,7 @@ private:
     AudioMixerWindow      *m_audioMixer;
     MidiMixerWindow       *m_midiMixer;
     BankEditorDialog      *m_bankEditor;
-    MarkerEditorDialog    *m_markerEditor;
+    MarkerEditor          *m_markerEditor;
     TempoView             *m_tempoView;
     TriggerSegmentManager *m_triggerSegmentManager;
     std::set<ControlEditorDialog *> m_controlEditors;
