@@ -52,6 +52,7 @@
 #include "document/RosegardenGUIDoc.h"
 #include "RosegardenApplication.h"
 #include "gui/configuration/GeneralConfigurationPage.h"
+#include "gui/configuration/AudioConfigurationPage.h"
 #include "gui/dialogs/AudioSplitDialog.h"
 #include "gui/dialogs/AudioManagerDialog.h"
 #include "gui/dialogs/DocumentConfigureDialog.h"
@@ -62,8 +63,8 @@
 #include "gui/editors/parameters/InstrumentParameterBox.h"
 #include "gui/editors/parameters/SegmentParameterBox.h"
 #include "gui/editors/parameters/TrackParameterBox.h"
-#include "gui/editors/segment/CompositionView.h"
-#include "gui/editors/segment/SegmentSelector.h"
+#include "gui/editors/segment/segmentcanvas/CompositionView.h"
+#include "gui/editors/segment/segmentcanvas/SegmentSelector.h"
 #include "gui/editors/segment/TrackEditor.h"
 #include "gui/seqmanager/SequenceManager.h"
 #include "gui/seqmanager/SequencerMapper.h"
@@ -167,6 +168,10 @@ RosegardenGUIView::RosegardenGUIView(bool showTrackLabels,
             SIGNAL(editRepeat(Segment*, timeT)),
             SLOT(slotEditRepeat(Segment*, timeT)));
 
+    connect(m_trackEditor->getSegmentCanvas(),
+            SIGNAL(setPointerPosition(timeT)),
+            doc, SLOT(slotSetPointerPosition(timeT)));
+
     connect(m_trackEditor,
             SIGNAL(droppedDocument(QString)),
             parent,
@@ -291,6 +296,7 @@ void RosegardenGUIView::updateSelectionContents()
     m_trackEditor->getSegmentCanvas()->updateSelectionContents();
 }
 
+/* hjj: WHAT DO DO WITH THIS ?
 void
 RosegardenGUIView::slotEditMetadata(QString name)
 {
@@ -304,6 +310,7 @@ RosegardenGUIView::slotEditMetadata(QString name)
 
     configDlg->show();
 }
+*/
 
 void RosegardenGUIView::slotEditSegment(Segment* segment)
 {
@@ -349,7 +356,23 @@ void RosegardenGUIView::slotEditSegment(Segment* segment)
                                           (unsigned int)GeneralConfigurationPage::NotationView));
 
         if (client == GeneralConfigurationPage::MatrixView) {
-            slotEditSegmentMatrix(segment);
+
+            bool isPercussion = false;
+            Track *track = getDocument()->getComposition().getTrackById
+                (segment->getTrack());
+            if (track) {
+                InstrumentId iid = track->getInstrument();
+                Instrument *instrument =
+                    getDocument()->getStudio().getInstrumentById(iid);
+                if (instrument && instrument->isPercussion()) isPercussion = true;
+            }
+
+            if (isPercussion) {
+                slotEditSegmentPercussionMatrix(segment);
+            } else {
+                slotEditSegmentMatrix(segment);
+            }
+
         } else if (client == GeneralConfigurationPage::EventView) {
             slotEditSegmentEventList(segment);
         } else {
@@ -477,8 +500,10 @@ RosegardenGUIView::createNotationView(std::vector<Segment *> segmentsToEdit)
             this, SLOT(slotEditSegmentsPercussionMatrix(std::vector<Segment *>)));
     connect(notationView, SIGNAL(openInEventList(std::vector<Segment *>)),
             this, SLOT(slotEditSegmentsEventList(std::vector<Segment *>)));
+/* hjj: WHAT DO DO WITH THIS ?
     connect(notationView, SIGNAL(editMetadata(QString)),
             this, SLOT(slotEditMetadata(QString)));
+*/
     connect(notationView, SIGNAL(editTriggerSegment(int)),
             this, SLOT(slotEditTriggerSegment(int)));
     connect(notationView, SIGNAL(staffLabelChanged(TrackId, QString)),
@@ -810,24 +835,30 @@ void RosegardenGUIView::slotEditSegmentAudio(Segment *segment)
 
     QString application = config->readEntry("externalaudioeditor", "");
 
-    if (application.isEmpty()) {
+    if (application == "") {
+        application = AudioConfigurationPage::getBestAvailableAudioEditor();
+    }
+
+    QStringList splitCommand = QStringList::split(" ", application);
+
+    if (splitCommand.size() == 0) {
+
         std::cerr << "RosegardenGUIView::slotEditSegmentAudio() - "
         << "external editor \"" << application.data()
         << "\" not found" << std::endl;
 
-
         KMessageBox::sorry(this,
-                           i18n("You've not yet defined an audio editor for Rosegarden to use.\nSee Settings -> Configure Rosegarden -> General -> External Editors."));
+                           i18n("You've not yet defined an audio editor for Rosegarden to use.\nSee Settings -> Configure Rosegarden -> Audio."));
 
         return ;
     }
 
-    QFileInfo *appInfo = new QFileInfo(application);
+    QFileInfo *appInfo = new QFileInfo(splitCommand[0]);
     if (appInfo->exists() == false || appInfo->isExecutable() == false) {
         std::cerr << "RosegardenGUIView::slotEditSegmentAudio() - "
-        << "can't execute \"" << application << "\""
-        << std::endl;
-        return ;
+                  << "can't execute \"" << splitCommand[0] << "\""
+                  << std::endl;
+        return;
     }
 
     AudioFile *aF = getDocument()->getAudioFileManager().
@@ -838,14 +869,13 @@ void RosegardenGUIView::slotEditSegmentAudio(Segment *segment)
         return ;
     }
 
-
     // wait cursor
     QApplication::setOverrideCursor(QCursor(Qt::waitCursor));
 
     // Prepare the process
     //
     KProcess *process = new KProcess();
-    (*process) << application;
+    (*process) << splitCommand;
     (*process) << QString(aF->getFilename().c_str());
 
     // Start it
@@ -1150,6 +1180,8 @@ RosegardenGUIView::updateMeters(SequencerMapper *mapper)
         if (!instrument)
             continue;
 
+		// This records the level of this instrument, not neccessarily
+		//  caused by notes on this particular track.
         LevelInfo &info = levels[instrumentId];
         LevelInfo &recInfo = recLevels[instrumentId];
 
@@ -1202,15 +1234,19 @@ RosegardenGUIView::updateMeters(SequencerMapper *mapper)
             }
 
         } else {
-
+			// Not audio or softsynth
             if (info.level == 0)
                 continue;
 
             if (getDocument()->getSequenceManager()->getTransportStatus()
                     != STOPPED) {
 
+				// The information in 'info' is specific for this instrument, not
+				//  for this track.
+				//m_trackEditor->getTrackButtons()->slotSetTrackMeter
+				//	(info.level / 127.0, track->getPosition());
                 m_trackEditor->getTrackButtons()->slotSetMetersByInstrument
-                (info.level / 127.0, instrumentId);
+                	(info.level / 127.0, instrumentId);
             }
         }
     }
@@ -1305,10 +1341,10 @@ void RosegardenGUIView::slotShowSegmentLabels(bool v)
 }
 
 void RosegardenGUIView::slotAddTracks(unsigned int nbTracks,
-                                      InstrumentId id)
+                                      InstrumentId id, int pos)
 {
-    RG_DEBUG << "RosegardenGUIView::slotAddTracks(" << nbTracks << ")" << endl;
-    m_trackEditor->slotAddTracks(nbTracks, id);
+    RG_DEBUG << "RosegardenGUIView::slotAddTracks(" << nbTracks << ", " << pos << ")" << endl;
+    m_trackEditor->slotAddTracks(nbTracks, id, pos);
 }
 
 void RosegardenGUIView::slotDeleteTracks(
