@@ -141,6 +141,7 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
                        bool drumMode)
         : EditView(doc, segments, 3, parent, "matrixview"),
         m_hlayout(&doc->getComposition()),
+        m_referenceRuler(new ZoomableMatrixHLayoutRulerScale(m_hlayout)),
         m_vlayout(),
         m_snapGrid(new SnapGrid(&m_hlayout)),
         m_lastEndMarkerTime(0),
@@ -195,12 +196,15 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
     QCanvas *tCanvas = new QCanvas(this);
 
     m_config->setGroup(MatrixViewConfigGroup);
-    if (m_config->readBoolEntry("backgroundtextures", false)) {
+    if (m_config->readBoolEntry("backgroundtextures-1.6-plus", true)) {
         QPixmap background;
         QString pixmapDir =
             KGlobal::dirs()->findResource("appdata", "pixmaps/");
-        if (background.load(QString("%1/misc/bg-paper-white.xpm").
-                            arg(pixmapDir))) {
+	// We now use a lined background for the non-percussion matrix,
+	// suggested and supplied by Alessandro Preziosi
+	QString backgroundPixmap = isDrumMode() ? "bg-paper-white.xpm" : "bg-matrix-lines.xpm";
+        if (background.load(QString("%1/misc/%2").
+                            arg(pixmapDir, backgroundPixmap))) {
             tCanvas->setBackgroundPixmap(background);
         }
     }
@@ -444,11 +448,13 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
     StandardRuler *topStandardRuler = new StandardRuler(getDocument(),
                                 &m_hlayout, int(xorigin), 25,
                                 false, getCentralWidget());
+    topStandardRuler->setSnapGrid(m_snapGrid);
     setTopStandardRuler(topStandardRuler);
 
     StandardRuler *bottomStandardRuler = new StandardRuler(getDocument(),
                                    &m_hlayout, 0, 25,
                                    true, getBottomWidget());
+    bottomStandardRuler->setSnapGrid(m_snapGrid);
     setBottomStandardRuler(bottomStandardRuler);
 
     topStandardRuler->connectRulerToDocPointer(doc);
@@ -498,12 +504,12 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
     //!!!    addPropertyViewRuler(BaseProperties::VELOCITY);
 
     m_chordNameRuler = new ChordNameRuler
-                       (&m_hlayout, doc, segments, 0, 20, getCentralWidget());
+                       (m_referenceRuler, doc, segments, 0, 20, getCentralWidget());
     m_chordNameRuler->setStudio(&getDocument()->getStudio());
     addRuler(m_chordNameRuler);
 
     m_tempoRuler = new TempoRuler
-                   (&m_hlayout, doc, factory(), 0, 24, false, getCentralWidget());
+                   (m_referenceRuler, doc, this, 0, 24, false, getCentralWidget());
     static_cast<TempoRuler *>(m_tempoRuler)->connectSignals();
     addRuler(m_tempoRuler);
 
@@ -517,16 +523,17 @@ MatrixView::MatrixView(RosegardenGUIDoc *doc,
 
     setCurrentSelection(0, false);
 
-    // Change this when the matrix view will have its own page
+    // Change this if the matrix view ever has its own page
     // in the config dialog.
-    setConfigDialogPageIndex(2);
+    setConfigDialogPageIndex(0);
 
     // default zoom
     m_config->setGroup(MatrixViewConfigGroup);
     double zoom = m_config->readDoubleNumEntry("Zoom Level",
                                                m_hZoomSlider->getCurrentSize());
     m_hZoomSlider->setSize(zoom);
-
+    m_referenceRuler->setHScaleFactor(zoom);
+    
     // Scroll view to centre middle-C and warp to pointer position
     //
     m_canvasView->scrollBy(0, m_staffs[0]->getCanvasYForHeight(60) / 2);
@@ -604,7 +611,7 @@ void MatrixView::readOptions()
     getToggleAction("show_chords_ruler")->setChecked(opt);
     slotToggleChordsRuler();
 
-    opt = m_config->readBoolEntry("Show Tempo Ruler", false);
+    opt = m_config->readBoolEntry("Show Tempo Ruler", true);
     getToggleAction("show_tempo_ruler")->setChecked(opt);
     slotToggleTempoRuler();
 
@@ -1077,14 +1084,12 @@ QSize MatrixView::getViewSize()
 
 void MatrixView::setViewSize(QSize s)
 {
-    MATRIX_DEBUG << "MatrixView::setViewSize() w = " << s.width()
-    << endl;
+    MATRIX_DEBUG << "MatrixView::setViewSize() w = " << s.width() << endl;
 
-    canvas()->resize(s.width(), s.height());
+    canvas()->resize(getXbyInverseWorldMatrix(s.width()), s.height());
     getCanvasView()->resizeContents(s.width(), s.height());
 
-    MATRIX_DEBUG << "MatrixView::setViewSize() contentsWidth = " << getCanvasView()->contentsWidth()
-    << endl;
+    MATRIX_DEBUG << "MatrixView::setViewSize() contentsWidth = " << getCanvasView()->contentsWidth() << endl;
 }
 
 void MatrixView::repaintRulers()
@@ -1579,7 +1584,8 @@ MatrixView::slotSetInsertCursorPosition(timeT time, bool scroll)
     m_staffs[0]->setInsertCursorPosition(m_hlayout, time);
 
     if (scroll && !getCanvasView()->isAutoScrolling()) {
-        getCanvasView()->slotScrollHoriz(static_cast<int>(getXbyWorldMatrix(m_hlayout.getXForTime(time))));
+        getCanvasView()->slotScrollHoriz
+            (static_cast<int>(getXbyWorldMatrix(m_hlayout.getXForTime(time))));
     }
 
     updateView();
@@ -1626,6 +1632,7 @@ void MatrixView::slotEditPaste()
         slotStatusHelpMsg(i18n("Couldn't paste at this point"));
     } else {
         addCommandToHistory(command);
+        setCurrentSelection(new EventSelection(command->getPastedEvents()));
     }
 }
 
@@ -2199,9 +2206,9 @@ MatrixView::initZoomToolbar()
     // Zoom labels
     //
     for (unsigned int i = 0; i < sizeof(factors) / sizeof(factors[0]); ++i) {
-        //         zoomSizes.push_back(duration44 / (defaultBarWidth44 * factors[i]));
+//         zoomSizes.push_back(duration44 / (defaultBarWidth44 * factors[i]));
 
-        //         zoomSizes.push_back(factors[i] / 2); // GROSS HACK - see in matrixstaff.h - BREAKS MATRIX VIEW, see bug 1000595
+//         zoomSizes.push_back(factors[i] / 2); // GROSS HACK - see in matrixstaff.h - BREAKS MATRIX VIEW, see bug 1000595
         zoomSizes.push_back(factors[i]);
     }
 
@@ -2231,6 +2238,13 @@ MatrixView::slotChangeHorizontalZoom(int)
     MATRIX_DEBUG << "MatrixView::slotChangeHorizontalZoom() : zoom factor = "
     << zoomValue << endl;
 
+    m_referenceRuler->setHScaleFactor(zoomValue);
+    
+    if (m_tempoRuler)
+        m_tempoRuler->repaint();
+    if (m_chordNameRuler)
+        m_chordNameRuler->repaint();
+
     // Set zoom matrix
     //
     QWMatrix zoomMatrix;
@@ -2411,8 +2425,7 @@ timeT
 MatrixView::getInsertionTime()
 {
     MatrixStaff *staff = m_staffs[0];
-    double ix = staff->getLayoutXOfInsertCursor();
-    return m_hlayout.getTimeForX(ix);
+    return staff->getInsertCursorTime(m_hlayout);
 }
 
 void
