@@ -654,6 +654,9 @@ protected:
     ChordNameRuler *m_chordNameRuler;
     QWidget        *m_tempoRuler;
 
+    // ruler used to scale tempo and chord name ruler
+    ZoomableMatrixHLayoutRulerScale* m_referenceRuler;
+
     std::vector<std::pair<int, int> > m_pendingInsertableNotes;
 
     bool m_playTracking;
