@@ -37,7 +37,7 @@
 #include "base/SegmentNotationHelper.h"
 #include "base/Staff.h"
 #include "base/ViewElement.h"
-#include "gui/editors/guitar/Fingering.h"
+#include "gui/editors/guitar/Chord.h"
 #include "gui/general/ProgressReporter.h"
 #include "gui/widgets/ProgressDialog.h"
 #include "NotationChord.h"
@@ -385,9 +385,10 @@ NotationHLayout::scanStaff(Staff &staff, timeT startTime, timeT endTime)
                 // contribute to a fixed area following the next chord
 
                 if (el->event()->has(Text::TextTypePropertyName) &&
-                        el->event()->get<String>(Text::TextTypePropertyName) ==
-                        Text::Lyric) {
-                    lyricWidth = m_npf->getTextWidth(Text(*el->event()));
+                    el->event()->get<String>(Text::TextTypePropertyName) ==
+                    Text::Lyric) {
+                    lyricWidth = std::max
+                        (lyricWidth, float(m_npf->getTextWidth(Text(*el->event()))));
                     NOTATION_DEBUG << "Setting lyric width to " << lyricWidth
                                    << " for text " << el->event()->get<String>(Text::TextPropertyName) << endl;
                 }
@@ -425,7 +426,7 @@ NotationHLayout::scanStaff(Staff &staff, timeT startTime, timeT endTime)
 
             } else {
 
-                NOTATION_DEBUG << "Found something I don't know about (type is " << el->event()->getType() << ")" << endl;
+//                NOTATION_DEBUG << "Found something I don't know about (type is " << el->event()->getType() << ")" << endl;
                 chunks.push_back(Chunk(el->event()->getSubOrdering(),
                                        getLayoutWidth(*el, key)));
             }
@@ -1327,6 +1328,7 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
         double barInset = notationStaff.getBarInset(barNo, repeatClefAndKey);
 
         NotationElement *lastDynamicText = 0;
+        int fretboardCount = 0;
         int count = 0;
 
         double offset = 0.0;
@@ -1359,7 +1361,7 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
             delta = 0;
             float fixed = 0;
 
-        if (el->event()->isa(Note::EventType)) {
+            if (el->event()->isa(Note::EventType)) {
                 long pitch = 0;
                 el->event()->get<Int>(PITCH, pitch);
                 NOTATION_DEBUG << "element is a " << el->event()->getType() << " (pitch " << pitch << ")" << endl;
@@ -1489,10 +1491,14 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
                 el->setLayoutX(ix + displacedX);
                 el->setLayoutAirspace(ix, delta - (ix - x));
 
-            } else if (el->event()->isa(Guitar::Fingering::EventType)) {
+            } else if (el->event()->isa(Guitar::Chord::EventType)) {
 
-                int fretboardWidth = m_npf->getLineSpacing() * 6;
-                el->setLayoutX(x - (fretboardWidth / 2));
+                int guitarChordWidth = m_npf->getLineSpacing() * 6;
+                el->setLayoutX(x - (guitarChordWidth / 2)
+                               + fretboardCount * (guitarChordWidth +
+                                                   m_npf->getNoteBodyWidth()/2)
+                               + displacedX);
+                ++fretboardCount;
 
             } else {
 
