@@ -48,7 +48,7 @@
 #include "base/Track.h"
 #include "base/ViewElement.h"
 #include "document/RosegardenGUIDoc.h"
-#include "gui/editors/guitar/Fingering.h"
+#include "gui/editors/guitar/Chord.h"
 #include "gui/general/LinedStaff.h"
 #include "gui/general/PixmapFunctions.h"
 #include "gui/general/ProgressReporter.h"
@@ -92,6 +92,7 @@ NotationStaff::NotationStaff(QCanvas *canvas, Segment *segment,
         m_colourQuantize(true),
         m_showUnknowns(true),
         m_showRanges(true),
+        m_showCollisions(true),
         m_printPainter(0),
         m_ready(false)
 {
@@ -102,6 +103,8 @@ NotationStaff::NotationStaff(QCanvas *canvas, Segment *segment,
     // Shouldn't change these  during the lifetime of the staff, really:
     m_showUnknowns = config->readBoolEntry("showunknowns", false);
     m_showRanges = config->readBoolEntry("showranges", true);
+    m_showCollisions = config->readBoolEntry("showcollisions", true);
+
     m_keySigCancelMode = config->readNumEntry("keysigcancelmode", 1);
 
     changeFont(fontName, resolution);
@@ -1254,12 +1257,12 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
                     pixmap = m_notePixmapFactory->makeUnknownPixmap();
                 }
             }
-        } else if (elt->event()->isa(Guitar::Fingering::EventType)) {
+        } else if (elt->event()->isa(Guitar::Chord::EventType)) {
 
-            // Create a fretboard pixmap
+            // Create a guitar chord pixmap
             try {
 
-                Guitar::Fingering arrangement (*elt->event());
+                Guitar::Chord chord (*elt->event());
 
                 /* UNUSED - for printing, just use a large pixmap as below
                 		    if (m_printPainter) {
@@ -1278,12 +1281,12 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
                 		    } else {
                 			*/
 
-                pixmap = m_notePixmapFactory->makeFretboardPixmap (arrangement,
+                pixmap = m_notePixmapFactory->makeGuitarChordPixmap (chord.getFingering(),
                          int(coords.first),
                          coords.second);
                 //		    }
-            } catch (Exception e) { // Fretboard ctor failed
-                NOTATION_DEBUG << "Bad fretboard event" << endl;
+            } catch (Exception e) { // GuitarChord ctor failed
+                NOTATION_DEBUG << "Bad guitar chord event" << endl;
             }
 
         } else {
@@ -1707,6 +1710,18 @@ NotationStaff::renderNote(ViewElementList::iterator &vli)
 
         // The normal on-screen case
 
+        bool collision = false;
+        QCanvasItem * haloItem = 0;
+        if (m_showCollisions) {
+            collision = elt->isColliding();
+            if (collision) {
+                // Make collision halo
+                QCanvasPixmap *haloPixmap = factory->makeNoteHaloPixmap(params);
+                haloItem = new QCanvasNotationSprite(*elt, haloPixmap, m_canvas);
+                haloItem->setZ(-1);
+            }
+        }
+
         QCanvasPixmap *pixmap = factory->makeNotePixmap(params);
 
         int z = 0;
@@ -1716,6 +1731,17 @@ NotationStaff::renderNote(ViewElementList::iterator &vli)
             z = 2;
 
         setPixmap(elt, pixmap, z, SplitToFit);
+
+        if (collision) {
+            // Display collision halo
+            LinedStaffCoords coords =
+                getCanvasCoordsForLayoutCoords(elt->getLayoutX(),
+                                               elt->getLayoutY());
+            double canvasX = coords.first;
+            int canvasY = coords.second;
+            elt->addCanvasItem(haloItem, canvasX, canvasY);
+            haloItem->show();
+        }
     }
 }
 
