@@ -34,7 +34,7 @@
 #include "base/NotationQuantizer.h"
 #include "base/Staff.h"
 #include "gui/general/ProgressReporter.h"
-#include "gui/editors/guitar/Fingering.h"
+#include "gui/editors/guitar/Chord.h"
 #include "NotationChord.h"
 #include "NotationElement.h"
 #include "NotationProperties.h"
@@ -248,11 +248,23 @@ NotationVLayout::scanStaff(Staff &staffBase, timeT, timeT)
 
             bool hasShifted = chord.hasNoteHeadShifted();
 
+            double y0 = -1E50;          // A very unlikely Y layout value
+
             for (unsigned int j = 0; j < chord.size(); ++j) {
 
                 el = static_cast<NotationElement*>(*chord[j]);
                 el->setLayoutY(staff.getLayoutYForHeight(h[j]));
 
+                // Look for collision
+                const double eps = 0.001;
+                Event *eel = el->event();
+                double y = el->getLayoutY();
+                if (eel->has("pitch")) {
+                    el->setIsColliding(fabs(y - y0) < eps);
+                    y0 = y;
+                }
+
+
                 // These calculations and assignments are pretty much final
                 // if the chord is not in a beamed group, but if it is then
                 // they will be reworked by NotationGroup::applyBeam, which
@@ -357,16 +369,18 @@ NotationVLayout::scanStaff(Staff &staffBase, timeT, timeT)
             } else if (el->event()->isa(Text::EventType)) {
 
                 std::string type = Text::UnspecifiedType;
-                el->event()->get
-                <String>(Text::TextTypePropertyName, type);
+                el->event()->get<String>(Text::TextTypePropertyName, type);
 
                 if (type == Text::Dynamic ||
                         type == Text::LocalDirection ||
                         type == Text::UnspecifiedType) {
-                    el->setLayoutY(staff.getLayoutYForHeight( -7) + displacedY);
-                } else if (type == Text::Lyric ||
-                           type == Text::Annotation) {
-                    el->setLayoutY(staff.getLayoutYForHeight( -13) + displacedY);
+                    el->setLayoutY(staff.getLayoutYForHeight(-7) + displacedY);
+                } else if (type == Text::Lyric) {
+                    long verse = 0;
+                    el->event()->get<Int>(Text::LyricVersePropertyName, verse);
+                    el->setLayoutY(staff.getLayoutYForHeight(-10 - 3 * verse) + displacedY);
+                } else if (type == Text::Annotation) {
+                    el->setLayoutY(staff.getLayoutYForHeight(-13) + displacedY);
                 } else {
                     el->setLayoutY(staff.getLayoutYForHeight(22) + displacedY);
                 }
@@ -393,9 +407,9 @@ NotationVLayout::scanStaff(Staff &staffBase, timeT, timeT)
                     el->setLayoutY(staff.getLayoutYForHeight( -9) + displacedY);
                 }
 
-            } else if (el->event()->isa(Guitar::Fingering::EventType)) {
+            } else if (el->event()->isa(Guitar::Chord::EventType)) {
 
-                el->setLayoutY(staff.getLayoutYForHeight(22));
+                el->setLayoutY(staff.getLayoutYForHeight(22) + displacedY);
             }
         }
     }
