@@ -46,9 +46,9 @@
 #include "commands/segment/SegmentEraseCommand.h"
 #include "commands/segment/SegmentInsertCommand.h"
 #include "commands/segment/SegmentRepeatToCopyCommand.h"
-#include "CompositionModel.h"
-#include "CompositionModelImpl.h"
-#include "CompositionView.h"
+#include "segmentcanvas/CompositionModel.h"
+#include "segmentcanvas/CompositionModelImpl.h"
+#include "segmentcanvas/CompositionView.h"
 #include "document/MultiViewCommandHistory.h"
 #include "document/RosegardenGUIDoc.h"
 #include "gui/application/RosegardenGUIApp.h"
@@ -134,7 +134,7 @@ TrackEditor::init(QWidget* rosegardenguiview)
 
     m_tempoRuler = new TempoRuler(m_rulerScale,
                                   m_doc,
-                                  RosegardenGUIApp::self()->factory(),
+                                  RosegardenGUIApp::self(),
                                   0.0,
                                   24,
                                   true,
@@ -413,11 +413,13 @@ void TrackEditor::paintEvent(QPaintEvent* e)
 }
 
 void TrackEditor::slotAddTracks(unsigned int nbNewTracks,
-                                InstrumentId id)
+                                InstrumentId id,
+                                int position)
 {
     Composition &comp = m_doc->getComposition();
 
-    AddTracksCommand* command = new AddTracksCommand(&comp, nbNewTracks, id);
+    AddTracksCommand* command = new AddTracksCommand(&comp, nbNewTracks, id,
+                                                     position);
     addCommandToHistory(command);
     slotReadjustCanvasSize();
 }
