@@ -41,7 +41,7 @@ public:
     HZoomable() : m_hScaleFactor(1.0) {}
 
     void setHScaleFactor(double dy) { m_hScaleFactor = dy; }
-    double getHScaleFactor()        { return m_hScaleFactor; }
+    double getHScaleFactor() const  { return m_hScaleFactor; }
 
 protected:    
     double m_hScaleFactor;
