@@ -422,8 +422,7 @@ public:
      * Move the insertion cursor to the layout-X coordinate
      * corresponding to the given time, and show it.
      */
-    virtual void setInsertCursorPosition
-    (HorizontalLayoutEngine&, timeT);
+    virtual void setInsertCursorPosition(HorizontalLayoutEngine&, timeT);
 
     /**
      * Move the insertion cursor to the layout-X coordinate
@@ -438,6 +437,11 @@ public:
      */
     virtual double getLayoutXOfInsertCursor() const;
 
+    /**
+     * Return the time of the insert cursor.
+     */
+    virtual timeT getInsertCursorTime(HorizontalLayoutEngine&) const;
+
     /**
      * Return the canvas coordinates of the top of the insert
      * cursor.
@@ -745,6 +749,8 @@ protected:
 
     QCanvasLine *m_pointer;
     QCanvasLine *m_insertCursor;
+    timeT m_insertCursorTime;
+    bool m_insertCursorTimeValid;
 };
 
 
