@@ -32,54 +32,135 @@
 #include "document/RosegardenGUIDoc.h"
 #include "gui/general/GUIPalette.h"
 #include "gui/general/HZoomable.h"
+#include "gui/dialogs/MarkerModifyDialog.h"
+#include "commands/edit/ModifyMarkerCommand.h"
+#include "document/MultiViewCommandHistory.h"
+#include <kxmlguifactory.h>
 #include <qbrush.h>
+#include <qcursor.h>
 #include <qfont.h>
 #include <qfontmetrics.h>
 #include <qpainter.h>
 #include <qpen.h>
 #include <qpoint.h>
+#include <qpopupmenu.h>
 #include <qrect.h>
 #include <qsize.h>
 #include <qstring.h>
 #include <qwidget.h>
+#include <klocale.h>
+#include <kaction.h>
+#include <kstddirs.h>
+#include <qtooltip.h>
 
 
 namespace Rosegarden
 {
 
 MarkerRuler::MarkerRuler(RosegardenGUIDoc *doc,
-                                   RulerScale *rulerScale,
-                                   int barHeight,
-                                   double xorigin,
-                                   QWidget* parent,
-                                   const char* name,
-                                   WFlags f)
+                         RulerScale *rulerScale,
+                         int barHeight,
+                         double xorigin,
+                         QWidget* parent,
+                         const char* name,
+                         WFlags f)
         : QWidget(parent, name, f),
         m_barHeight(barHeight),
         m_xorigin(xorigin),
         m_currentXOffset(0),
-        m_width( -1),
+        m_width(-1),
+        m_clickX(0),
+        m_menu(0),
         m_doc(doc),
-        m_rulerScale(rulerScale)
+        m_rulerScale(rulerScale),
+        m_parentMainWindow(dynamic_cast<KMainWindow*>(doc->parent()))
 {
+    // If the parent window has a main window above it, we need to use
+    // that as the parent main window, not the document's parent.
+    // Otherwise we'll end up adding all actions to the same
+    // (document-level) action collection regardless of which window
+    // we're in.
+    QObject *probe = parent;
+    while (probe && !dynamic_cast<KMainWindow *>(probe)) probe = probe->parent();
+    if (probe) m_parentMainWindow = dynamic_cast<KMainWindow *>(probe);
+
     //    m_barFont = new QFont("helvetica", 12);
     //    m_barFont->setPixelSize(12);
     m_barFont = new QFont();
     m_barFont->setPointSize(10);
+
+    QString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    QIconSet icon;
+
+    // Use the event insert, delete, edit icons because they are
+    // actually generic enough to serve for anything.  Let's hope they
+    // don't become more event-specific in future...
+
+    icon = QIconSet(QPixmap(pixmapDir + "/toolbar/event-insert.png"));
+    new KAction(i18n("Insert Marker"), icon, 0, this,
+             SLOT(slotInsertMarkerHere()), actionCollection(),
+             "insert_marker_here");
+    
+    new KAction(i18n("Insert Marker at Playback Position"), 0, this,
+             SLOT(slotInsertMarkerAtPointer()), actionCollection(),
+             "insert_marker_at_pointer");
+
+    icon = QIconSet(QPixmap(pixmapDir + "/toolbar/event-delete.png"));
+    new KAction(i18n("Delete Marker"), icon, 0, this,
+             SLOT(slotDeleteMarker()), actionCollection(),
+             "delete_marker");
+    
+    icon = QIconSet(QPixmap(pixmapDir + "/toolbar/event-edit.png"));
+    new KAction(i18n("Edit Marker..."), icon, 0, this,
+                 SLOT(slotEditMarker()), actionCollection(),
+                 "edit_marker");
+
+    QToolTip::add
+        (this, i18n("Click on a marker to move the playback pointer.\nShift-click to set a range between markers.\nDouble-click to open the marker editor."));
 }
 
 MarkerRuler::~MarkerRuler()
 {
     delete m_barFont;
+    // we have to do this so that the menu is re-created properly
+    // when the main window is itself recreated (on a File->New for instance)
+    KXMLGUIFactory* factory = m_parentMainWindow->factory();
+    if (factory)
+        factory->removeClient(this);
 }
 
-void MarkerRuler::scrollHoriz(int x)
+void
+MarkerRuler::createMenu()
+{             
+    setXMLFile("markerruler.rc");
+    
+    KXMLGUIFactory* factory = m_parentMainWindow->factory();
+    factory->addClient(this);
+
+    QWidget* tmp = factory->container("marker_ruler_menu", this);
+
+//    if (!tmp) {
+//        RG_DEBUG << "MarkerRuler::createMenu() menu not found\n"
+//                 << domDocument().toString(4) << endl;
+//    }
+    
+    m_menu = dynamic_cast<QPopupMenu*>(tmp);
+    
+    if (!m_menu) {
+        RG_DEBUG << "MarkerRuler::createMenu() failed\n";
+    }
+}
+
+
+void 
+MarkerRuler::scrollHoriz(int x)
 {
     m_currentXOffset = static_cast<int>( -x / getHScaleFactor());
     repaint();
 }
 
-QSize MarkerRuler::sizeHint() const
+QSize 
+MarkerRuler::sizeHint() const
 {
     int lastBar =
         m_rulerScale->getLastVisibleBar();
@@ -90,14 +171,133 @@ QSize MarkerRuler::sizeHint() const
     return QSize(std::max(int(width), m_width), m_barHeight);
 }
 
-QSize MarkerRuler::minimumSizeHint() const
+QSize 
+MarkerRuler::minimumSizeHint() const
 {
     double firstBarWidth = m_rulerScale->getBarWidth(0) + m_xorigin;
 
     return QSize(static_cast<int>(firstBarWidth), m_barHeight);
 }
 
-void MarkerRuler::paintEvent(QPaintEvent*)
+void
+MarkerRuler::slotInsertMarkerHere()
+{
+    emit addMarker(getClickPosition());    
+}
+
+void
+MarkerRuler::slotInsertMarkerAtPointer()
+{
+    emit addMarker(m_doc->getComposition().getPosition());
+}
+
+void
+MarkerRuler::slotDeleteMarker()
+{
+    RG_DEBUG << "MarkerRuler::slotDeleteMarker()\n";
+    
+    Rosegarden::Marker* marker = getMarkerAtClickPosition();
+    
+    if (marker)
+        emit deleteMarker(marker->getTime(),
+                          marker->getName(),
+                          marker->getDescription());                          
+}
+
+void
+MarkerRuler::slotEditMarker()
+{
+    Rosegarden::Marker* marker = getMarkerAtClickPosition();
+
+    if (!marker) return;
+
+    // I think the ruler should be doing all this stuff itself, or
+    // emitting signals connected to a dedicated marker model object,
+    // not just relying on the app object.  Same goes for practically
+    // everything else we do.  Hey ho.  Having this here is
+    // inconsistent with the other methods, so if anyone wants to move
+    // it, be my guest.
+
+    MarkerModifyDialog dialog(this, &m_doc->getComposition(), marker);
+    if (dialog.exec() == QDialog::Accepted) {
+        ModifyMarkerCommand *command =
+            new ModifyMarkerCommand(&m_doc->getComposition(),
+                                    dialog.getOriginalTime(),
+                                    dialog.getTime(),
+                                    qstrtostr(dialog.getName()),
+                                    qstrtostr(dialog.getDescription()));
+        m_doc->getCommandHistory()->addCommand(command);
+    }
+}
+
+timeT
+MarkerRuler::getClickPosition()
+{
+    timeT t = m_rulerScale->getTimeForX
+              (m_clickX - m_xorigin - m_currentXOffset);
+
+    return t;
+}
+
+Rosegarden::Marker*
+MarkerRuler::getMarkerAtClickPosition()
+{
+    QRect clipRect = visibleRect();
+
+    int firstBar = m_rulerScale->getBarForX(clipRect.x() -
+                                            m_currentXOffset -
+                                            m_xorigin);
+    int lastBar = m_rulerScale->getLastVisibleBar();
+    if (firstBar < m_rulerScale->getFirstVisibleBar()) {
+        firstBar = m_rulerScale->getFirstVisibleBar();
+    }
+
+    Composition &comp = m_doc->getComposition();
+    Composition::markercontainer markers = comp.getMarkers();
+
+    timeT start = comp.getBarStart(firstBar);
+    timeT end = comp.getBarEnd(lastBar);
+
+    // need these to calculate the visible extents of a marker tag
+    QPainter painter(this);
+    painter.setFont(*m_barFont);
+    QFontMetrics metrics = painter.fontMetrics();
+
+    for (Composition::markerconstiterator i = markers.begin();
+            i != markers.end(); ++i) {
+
+        if ((*i)->getTime() >= start && (*i)->getTime() < end) {
+
+            QString name(strtoqstr((*i)->getName()));
+
+            int x = m_rulerScale->getXForTime((*i)->getTime())
+                    + m_xorigin + m_currentXOffset;
+
+            int width = metrics.width(name) + 5;
+
+            int nextX = -1;
+            Composition::markerconstiterator j = i;
+            ++j;
+            if (j != markers.end()) {
+                nextX = m_rulerScale->getXForTime((*j)->getTime())
+                        + m_xorigin + m_currentXOffset;
+            }
+
+            if (m_clickX >= x && m_clickX <= x + width) {
+
+                if (nextX < x || m_clickX <= nextX) {
+
+                    return *i;
+                }
+            }
+        }
+    }
+
+    return 0L;
+}
+    
+void
+MarkerRuler::paintEvent(QPaintEvent*)
 {
     QPainter painter(this);
     painter.setFont(*m_barFont);
@@ -223,13 +423,30 @@ MarkerRuler::mousePressEvent(QMouseEvent *e)
     RG_DEBUG << "MarkerRuler::mousePressEvent: x = " << e->x() << endl;
 
     if (!m_doc || !e)
-        return ;
+        return;
+
+    m_clickX = e->x();
+    Rosegarden::Marker* clickedMarker = getMarkerAtClickPosition();
+    
+    // if right-click, show popup menu
+    //
+    if (e->button() == RightButton) {
+        if (!m_menu)
+            createMenu();
+        if (m_menu) {
+            actionCollection()->action("delete_marker")->setEnabled(clickedMarker != 0);
+            actionCollection()->action("edit_marker")->setEnabled(clickedMarker != 0);
+            m_menu->exec(QCursor::pos());
+        }
+        return;       
+    }
+            
     bool shiftPressed = ((e->state() & Qt::ShiftButton) != 0);
 
     Composition &comp = m_doc->getComposition();
     Composition::markercontainer markers = comp.getMarkers();
 
-    if (shiftPressed) {
+    if (shiftPressed) { // set loop
 
         timeT t = m_rulerScale->getTimeForX
                   (e->x() - m_xorigin - m_currentXOffset);
@@ -252,58 +469,10 @@ MarkerRuler::mousePressEvent(QMouseEvent *e)
         if (prev > 0)
             emit setLoop(prev, comp.getEndMarker());
 
-        return ;
-    }
+    } else { // set pointer to clicked marker
 
-    QRect clipRect = visibleRect();
-
-    int firstBar = m_rulerScale->getBarForX(clipRect.x() -
-                                            m_currentXOffset -
-                                            m_xorigin);
-    int lastBar = m_rulerScale->getLastVisibleBar();
-    if (firstBar < m_rulerScale->getFirstVisibleBar()) {
-        firstBar = m_rulerScale->getFirstVisibleBar();
-    }
-
-    timeT start = comp.getBarStart(firstBar);
-    timeT end = comp.getBarEnd(lastBar);
-
-    // need these to calculate the visible extents of a marker tag
-    QPainter painter(this);
-    painter.setFont(*m_barFont);
-    QFontMetrics metrics = painter.fontMetrics();
-
-    for (Composition::markerconstiterator i = markers.begin();
-            i != markers.end(); ++i) {
-
-        if ((*i)->getTime() >= start && (*i)->getTime() < end) {
-
-            QString name(strtoqstr((*i)->getName()));
-
-            int x = m_rulerScale->getXForTime((*i)->getTime())
-                    + m_xorigin + m_currentXOffset;
-
-            int width = metrics.width(name) + 5;
-
-            int nextX = -1;
-            Composition::markerconstiterator j = i;
-            ++j;
-            if (j != markers.end()) {
-                nextX = m_rulerScale->getXForTime((*j)->getTime())
-                        + m_xorigin + m_currentXOffset;
-            }
-
-            if (e->x() >= x && e->x() <= x + width) {
-
-                if (nextX < x || e->x() <= nextX) {
-
-                    RG_DEBUG << "MarkerRuler::mousePressEvent: setting pointer to " << (*i)->getTime() << endl;
-
-                    emit setPointerPosition((*i)->getTime());
-                    return ;
-                }
-            }
-        }
+        if (clickedMarker)
+            emit setPointerPosition(clickedMarker->getTime());
     }
 }
 
