@@ -47,7 +47,7 @@ class PitchDragLabel : public QWidget
     Q_OBJECT
 public:
     PitchDragLabel(QWidget *parent,
-                             int defaultPitch = 60);
+    	int defaultPitch = 60, bool defaultSharps = true);
     ~PitchDragLabel();
 
     int getPitch() const { return m_pitch; }
@@ -56,11 +56,16 @@ public:
 
 signals:
     void pitchDragged(int);
+    // pitch, octave, step
+    void pitchDragged(int,int,int);
     void pitchChanged(int); // mouse release
+    // pitch, octave, step
+    void pitchChanged(int,int,int); // mouse release
     void preview(int);
 
 public slots:
     void slotSetPitch(int);
+    void slotSetPitch(int,int,int);
     
 protected:
     virtual void paintEvent(QPaintEvent *);
@@ -69,7 +74,11 @@ protected:
     virtual void mouseMoveEvent(QMouseEvent *e);
     virtual void wheelEvent(QWheelEvent *e);
 
-    void calculatePixmap(bool useSharps) const;
+    void calculatePixmap() const;
+    void calculatePixmap(int pitch, int octave, int step) const;
+
+	/** emits 'pitchChanged' events, both diatonic and chromatic */
+	void emitPitchChange();
 
     mutable QPixmap m_pixmap;
 
@@ -77,6 +86,8 @@ protected:
     int m_clickedY;
     int m_clickedPitch;
     bool m_clicked;
+    
+    bool m_usingSharps;
 
     NotePixmapFactory *m_npf;
 };
