@@ -245,11 +245,9 @@ QuantizeParameters::QuantizeParameters(QWidget *parent,
         m_rebeam->setChecked
         (config->readBoolEntry("quantizerebeam", true));
         m_makeViable->setChecked
-        (config->readBoolEntry("quantizemakeviable",
-                               defaultQuantizer == Notation));
+        (config->readBoolEntry("quantizemakeviable", false));
         m_deCounterpoint->setChecked
-        (config->readBoolEntry("quantizedecounterpoint",
-                               defaultQuantizer == Notation));
+        (config->readBoolEntry("quantizedecounterpoint", false));
         m_articulate->setChecked
         (config->readBoolEntry("quantizearticulate", true));
         advanced = config->readBoolEntry("quantizeshowadvanced", false);
