@@ -21,6 +21,7 @@
 
 #include <iostream>
 #include <cassert>
+#include <cstdlib>
 
 #include "DSSIPluginInstance.h"
 #include "PluginIdentifier.h"
@@ -345,7 +346,7 @@ DSSIPluginInstance::initialiseGroupMembership()
 
 DSSIPluginInstance::~DSSIPluginInstance()
 {
-    std::cerr << "DSSIPluginInstance::~DSSIPluginInstance" << std::endl;
+//    std::cerr << "DSSIPluginInstance::~DSSIPluginInstance" << std::endl;
 
     detachFromGroup();
 
